function Marinus () {};

// Variables
var month_names = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
var basemap_id = 'ktransier.map-xya6pg28';

// Helper functions
function popup(point) {
  var url = "";
  var start_date = "";
  var summary = "";
  if (point.url && point.id) {url = "<a href=" + point.url + point.id + "' target=_blank>" + point.id + "</a> | "};
  if (point.start_date) { start_date = formatDate(point.start_date) };
  if (point.summary) { summary = "<p class=map-popup-summary>" + point.summary + "</p>"};
  return url + start_date + summary;
}

function formatDate(date) {
  var date = new Date(date);
  var month = month_names[date.getMonth()];
  var day = date.getDate();
  var year = date.getFullYear();
  return month + " " + day + ", " + year;
};

function offset_coordinates(latitude, longitude, min_offset, max_offset){
  min_offset = min_offset / 111.32;
  max_offset = max_offset / 111.32;
  latitude = latitude + Math.random() * (max_offset - min_offset) + min_offset;
  longitude = longitude + Math.random() * (max_offset - min_offset) + min_offset;
  return [latitude, longitude];
}

//todo: build seperate generatemarkers and generatemarkercluster functions
function generateMarkers(data, map, options) {
  // Set variables
  var markers, marker, marker_radius, latitude_offset, longitude_offset;

  // Build marker cluster layer
  markers = new L.MarkerClusterGroup({maxClusterRadius: 20, spiderfyOnMaxZoom: true});
  // Add marker layers to marker cluster
  for (i = 0; i < data.length; i++) {
    if (data[i].latitude && data[i].longitude) {
      var latitude = Number(data[i].latitude);
      var longitude = Number(data[i].longitude);
      var coordinates = [latitude, longitude];

      if (options.offset) {
        coordinates = offset_coordinates(latitude, longitude, options.max_offset, options.min_offset);
      }

      marker = L.circleMarker(coordinates,
        {
          stroke: true,
          color: '#fff',
          weight: 2,
          opacity: 1,
          fill: true,
          fillColor: data[i].marker_color,
          fillOpacity: 1
        });
      marker.bindPopup(popup(data[i]));
      if (data[i].marker_radius) {
        marker_radius = data[i].marker_radius;
      } else if (options.marker_radius) {
        marker_radius = options.marker_radius
      } else {
        marker_radius = 1;
      };
      marker.setRadius(marker_radius);
      map.addLayer(marker);
    };
  };

  // Add marker cluster to basemap
  // map.addLayer(markers);
};

// Build Map
Marinus.build = function (options) {
  var map = L.mapbox.map(options.map_id, basemap_id, {
    zoomControl: false,
    scrollWheelZoom: false
  }).setView([options.lat, options.long], options.zoom);
  L.control.scale().addTo(map); // Load scale
  map.addControl(new L.Control.ZoomFS()); // Load map controls

  // Build legend
  if (options.legend) {
    map.legendControl.addLegend(document.getElementById(options.map_id + '_legend').innerHTML);
  };

  if (options.csv_url) {
    $.get(options.csv_url, function(data) {
      data = $.csv.toObjects(data);
      generateMarkers(data, map, options)
    });
  };

  $('.mapbox-control-info').addClass('hide');
};
